/*                                                               -*- C -*-
 *  $Id: aaf.h,v 1.11 1996/06/20 18:37:52 tf Exp $
 *
 *  Support library for the astrological exchange format AAF as of 01-Jan-93
 *  which has been developed by Martin Grams <0761409591-0001@T-online.de>
 *
 *  Copyright (C) 1995-96 by Tobias Ferber, ferber@rpk.mach.uni-karlsruhe.de
 */

/* This file is part of the AAF Library.

The AAF Library is free software; you can redistribute it and/or
modify it under the terms of the GNU Library General Public License as
published by the Free Software Foundation; either version 2 of the
License, or (at your option) any later version.

The AAF Library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Library General Public License for more details.

You should have received a copy of the GNU Library General Public
License along with the AAF Library; see the file COPYING.LIB.  If
not, write to the Free Software Foundation, Inc., 675 Mass Ave,
Cambridge, MA 02139, USA.  */

#ifndef __AAF_H__
#define __AAF_H__

#include <ctype.h>
#include <string.h>

#include "ansidecl.h"

/* Yes, there some preprocessors out there which do not
   define the following macros... */

#ifndef __FILE__
#define __FILE__ "AAF"
#endif /* !__FILE__ */

#ifndef __LINE__
#define __LINE__ 1
#endif /* !__LINE__ */

/*
 *  Data tables
 */

/* aaftab.c */
extern char *  aaftab_aspects[];
extern double  aaftab_aspect_angles[];
extern char *  aaftab_signs[];
extern char *  aaftab_house_systems[];
extern char *  aaftab_objects[];
extern char *  aaftab_countries[];
extern char *  aaftab_chunk_ids[];

/****** aaf/aafchunk *********************************************************
*
* NAME
*    aafchunk -- The basic chunk structure for the AAF library
*
* SYNOPSIS
*    #include "aaf.h"
*
* DESCRIPTION
*    FIXME!
*
******************************************************************************
*
* The AAF chunk is the basic unit
*/

typedef struct aafchunk {
  struct aafchunk *succ, *pred, *parent, *child;
  char *id, *strval, **fields;
  int num_fields;               
} aafchunk_t;

/*
 *  Prototypes
 */

#if defined(__cplusplus) || defined(cplusplus)
extern "C" {
#endif /* C++ */

#ifndef HAVE_WORKING_CONST
#define const
#endif /* !HAVE_WORKING_CONST */
  
/* stricmp.c */  
#ifndef HAVE_STRICMP
#ifdef HAVE_STRCASECMP
#define stricmp(s,t)  strcasecmp(s,t)
#else /* !HAVE_STRCASECMP */
extern int EXFUN( stricmp, (const char *, const char *) );
#endif /* !HAVE_STRCASECMP */
#endif /* !HAVE_STRICMP */

/* strnicmp.c */
#ifndef HAVE_STRNICMP
#ifdef HAVE_STRNCASECMP
#define strnicmp(s,t,n) strncasecmp(s,t,n)
#else /* !HAVE_STRNCASECMP */
extern int EXFUN( strnicmp, (const char *, const char *, int) );
#endif /* !HAVE_STRNCASECMP */
#endif /* !HAVE_STRNICMP */

/* strdup.c */
#ifndef HAVE_STRDUP
extern char * EXFUN( strdup, (const char *) );
#endif /* !HAVE_STRDUP */

/* strstrip.c */
#ifndef HAVE_STRSTRIP
extern char * EXFUN( strstrip, (char *s, const char *lr) );
#endif /* !HAVE_STRSTIP */

/* strsplit.c */
#ifndef HAVE_STRSPLIT
extern int EXFUN( strsplit, (const char *, const char *, int, char ***) );
#endif /* !HAVE_STRSPLIT */

/* aaf.c */
#ifndef HAVE_STRCHR
extern char * EXFUN( strchr, (const char *s, int c) );
#endif /* !HAVE_STRCHR */

/* aaf.c */
extern int            EXFUN( aaf_error,             (char *file,
						     int line,
						     char *fmt, ...) );

extern FILE *         EXFUN( aaf_open,              (char *fname) );
extern FILE *         EXFUN( aaf_close,             (FILE *fp) );
extern char *         EXFUN( aaf_read,              (FILE *fp) );

/* aafchunk.c */
extern aafchunk_t *   EXFUN( aafchunk_new,          (char *id, char *strval) );
extern aafchunk_t *   EXFUN( aafchunk_dispose,      (aafchunk_t *this) );
extern int            EXFUN( aafchunk_set,          (aafchunk_t *this,
						     char *new_id, char *new_strval) );
extern aafchunk_t *   EXFUN( aafchunk_head,         (aafchunk_t *this) );
extern aafchunk_t *   EXFUN( aafchunk_tail,         (aafchunk_t *this) );
extern aafchunk_t *   EXFUN( aafchunk_top,          (aafchunk_t *this) );
extern int            EXFUN( aafchunk_insert_after, (aafchunk_t *this, 
						     aafchunk_t *here) );
extern aafchunk_t *   EXFUN( aafchunk_remove,       (aafchunk_t *this) );
extern aafchunk_t *   EXFUN( aafchunk_cut,          (aafchunk_t *this) );
extern int            EXFUN( aafchunk_fold,         (aafchunk_t *this) );
extern aafchunk_t *   EXFUN( aafchunk_read,         (FILE *fp) );
extern aafchunk_t *   EXFUN( aafchunk_read_until,   (FILE *fp,
						     char *id,
						     aafchunk_t *this) );
extern aafchunk_t *   EXFUN( aafchunk_read_all,     (FILE *fp) );
extern void           EXFUN( aafchunk_debug,        (aafchunk_t *this, int level) );
extern int            EXFUN( aafchunk_strsplit,     (aafchunk_t *this,
						     char *glue,
						     int strip) );

/* aafkey.c */
extern long *         EXFUN( aafkey_retrieve,       (FILE *db) );
extern aafchunk_t *   EXFUN( aafchunk_fetchkey,     (FILE *db, long key) );

/* aaftab.c */
extern int            EXFUN( aaf_table_lookup,      (char **table, 
						     char *str, size_t len) );

/* aafparse.c */
extern int            EXFUN( aaf_parse_date,        (char *str,
						     int *var_mday,
						     int *var_mon,
						     int *var_year,
						     char **var_cal) );

extern int            EXFUN( aaf_parse_time,        (char *str,
						     int *var_hour,
						     int *var_min,
						     int *var_sec,
						     char **var_pos) );

extern int            EXFUN( aaf_parse_pos,         (char *str,
						     int *var_deg,
						     int *var_sign,
						     int *var_min,
						     int *var_sec) );

extern int            EXFUN( aaf_parse_aspect,      (char *str,
						     int *var_lobj,
						     int *var_aspect,
						     int *var_robj,
						     int *var_plusminus,		 
						     int *var_deg,
						     int *var_min,
						     int *var_sec) );
#if defined(__cplusplus) || defined(cplusplus)
}
#endif /* C++ */


#endif /* !__AAF_H__ */
